{% load i18n %}

{% if not user.is_authenticated %}
<a class="navbar-item" href="{% url "login" %}">{% trans "Log In" %}</a>
{% else %}
<div class="navbar-item has-dropdown is-hoverable">
  <a class="navbar-link">{{ user.username }}</a>
  <div class="navbar-dropdown">
    {% block navbar_user_list %}{% endblock navbar_user_list %}
    {% if user.is_staff %}
    <a class="navbar-item" href="{% url "admin:index" %}">{% trans "Admin" %}</a>
    {% endif %}
    <a class="navbar-item" href="{% url "logout" %}">{% trans "Log Out" %}</a>
  </div>
</div>
{% endif %}
