{% extends 'karvi/base/__base.html' %}

{% block content %}
  <div class="columns">
    <section class="column is-9">
      {% block section %}{% endblock section %}
    </section>
    <aside class="column">
      {% block aside %}{% endblock aside %}
    </aside>
  </div>
{% endblock content %}
