{% load karvi_alerts %}

{% if messages %}
  {% for message in messages %}
    {% if message.level == DEFAULT_MESSAGE_LEVELS.DEBUG %}
      {% karvi_alert message 'is-warning' %}
    {% elif message.level == DEFAULT_MESSAGE_LEVELS.INFO %}
      {% karvi_alert message 'is-info' %}
    {% elif message.level == DEFAULT_MESSAGE_LEVELS.SUCCESS %}
      {% karvi_alert message 'is-success' %}
    {% elif message.level == DEFAULT_MESSAGE_LEVELS.WARNING %}
      {% karvi_alert message 'is-warning' %}
    {% elif message.level == DEFAULT_MESSAGE_LEVELS.ERROR %}
      {% karvi_alert message 'is-danger' %}
    {% else %}
      {% karvi_alert message %}
    {% endif %}
  {% endfor %}
{% endif %}
