{% load karvi %}

<nav class="navbar is-fixed-top is-dark" role="navigation" aria-label="main navigation">
    <div class="navbar-brand">
      <a class="navbar-item" href="{% karvi_settings "homepage" %}">{% karvi_settings "sitename" %}</a>
      <a role="button" class="navbar-burger" data-target="mainNavbar" aria-label="menu" aria-expanded="false">
        <span aria-hidden="true"></span>
        <span aria-hidden="true"></span>
        <span aria-hidden="true"></span>
      </a>
    </div>
    <div class="navbar-menu" id="mainNavbar">
      <div class="navbar-start">
        {% block navbar_menu %}{% endblock navbar_menu %}
      </div>
      <div class="navbar-end">
        {% block navbar_user %}
          {% include "karvi/navbar/__user.html" %}
        {% endblock navbar_user %}
      </div>
    </div>
  </nav>
