{% if not dismissible %}
  {% if not title %}
    <div class="notification {{ type }}" role="alert">
      {{ message }}
    </div>
  {% else %}
    <div class="notification {{ type }}" role="alert">
      <h4>{{ title }}</h4>
      {{ message }}
    </div>
  {% endif %}
{% else %}
  {% if not title %}
    <div class="notification {{ type }}" role="alert">
      <button class="delete"></button>
      {{ message }}
    </div>
  {% else %}
    <div class="notification {{ type }}" role="alert">
      <button class="delete"></button>
      <h4>{{ title }}</h4>
      {{ message }}
    </div>
  {% endif %}
{% endif %}
