{% load staticfiles i18n karvi %}

{% get_current_language as LANGUAGE_CODE %}

<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE }}">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <meta http-equiv="X-UA-Compatible" content="ie=edge">
  {% block title %}
    <title>{% karvi_settings "sitename" %}</title>
  {% endblock title %}
  {% block css %}
    <link rel="stylesheet" href="{% static "karvi/css/karvi.css" %}">
  {% endblock css %}
</head>

{% block body_config %}
  <body class="has-navbar-fixed-top">
{% endblock body_config %}
  {% block body %}
    {% block navbar %}
      {% include "karvi/navbar/__base.html" %}
    {% endblock navbar %}

    <main role="main" class="section">
      {% block alerts %}
        {% include "karvi/base/__messages.html" %}
      {% endblock alerts %}
      {% block breadcrumb %}{% endblock breadcrumb %}
      {% block content %}{% endblock content %}
    </main>

    <footer class="footer">
      {% block footer %}{% endblock footer %}
    </footer>
  {% endblock body %}

  {% block js %}
    <script type="text/javascript" src="{% static "karvi/js/karvi.js" %}"></script>
    <script defer src="https://use.fontawesome.com/releases/v5.1.0/js/all.js"></script>
  {% endblock js %}
</body>
</html>
